default_client_options = {
    "src": "outlook",
    "weadegreetype": "C",
    "culture": "en-US"
}

base_url = "https://weather.service.msn.com/find.aspx"

empty_func = lambda d: d